==> alg-feature-1.32.2-20200306.062048-2-sources.jar: cn/com/duiba/nezha/alg/feature/vo/ActTitleFeatureDo.java <==
package cn.com.duiba.nezha.alg.feature.vo;

import java.io.Serializable;

/**
 * Created by pc on 2019/2/21.
 */
public class ActTitleFeatureDo implements Serializable {
    private static final long serialVersionUID = 6695201251295150673L;


    /**
     * 静态特征，推荐入参提供
     */

    private Long appId; //媒体ID f.请求 f201000-f201001

    private Long slotId;  //广告位ID f.请求 f108000-f108001

    private Long activityId; //活动IDf.请求 f302000-f302001

    private Long activityPage; //自定义活动ID f.请求 新增，待编码 311001

    private String activitySkin; //皮肤ID f.请求 新增，待编码

    private Long dsm2A; //返回拦截类型 f.请求 新增，待编码  312001


    private Long areaCode; // 地域 f4010030


    /**
     * 动态特征，打印日志补全、算法推荐内部补全
     */
    private Long activityTitleId; //主标题ID.请求

    private Long activitySubTitleId; //副标题ID.请求

    private Long activityTitleTagId; //主标题标签ID.请求

    private Long activitySubTitleTagId; //副标题标签ID.请求

    private String activityTitleName; //主标题名称.请求

    private String activitySubTitleName; //副标题名称.请求


    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getActivityPage() {
        return activityPage;
    }

    public void setActivityPage(Long activityPage) {
        this.activityPage = activityPage;
    }

    public String getActivitySkin() {
        return activitySkin;
    }

    public void setActivitySkin(String activitySkin) {
        this.activitySkin = activitySkin;
    }

    public Long getDsm2A() {
        return dsm2A;
    }

    public void setDsm2A(Long dsm2A) {
        this.dsm2A = dsm2A;
    }

    public Long getAreaCode() {
        return areaCode;
    }

    public void setAreaCode(Long areaCode) {
        this.areaCode = areaCode;
    }

    public Long getActivityTitleId() {
        return activityTitleId;
    }

    public void setActivityTitleId(Long activityTitleId) {
        this.activityTitleId = activityTitleId;
    }

    public Long getActivitySubTitleId() {
        return activitySubTitleId;
    }

    public void setActivitySubTitleId(Long activitySubTitleId) {
        this.activitySubTitleId = activitySubTitleId;
    }

    public Long getActivityTitleTagId() {
        return activityTitleTagId;
    }

    public void setActivityTitleTagId(Long activityTitleTagId) {
        this.activityTitleTagId = activityTitleTagId;
    }

    public Long getActivitySubTitleTagId() {
        return activitySubTitleTagId;
    }

    public void setActivitySubTitleTagId(Long activitySubTitleTagId) {
        this.activitySubTitleTagId = activitySubTitleTagId;
    }

    public String getActivityTitleName() {
        return activityTitleName;
    }

    public void setActivityTitleName(String activityTitleName) {
        this.activityTitleName = activityTitleName;
    }

    public String getActivitySubTitleName() {
        return activitySubTitleName;
    }

    public void setActivitySubTitleName(String activitySubTitleName) {
        this.activitySubTitleName = activitySubTitleName;
    }
}

==> alg-feature-1.47.4-sources.jar: cn/com/duiba/nezha/alg/feature/vo/ActTitleFeatureDo.java <==
package cn.com.duiba.nezha.alg.feature.vo;

import java.io.Serializable;

/**
 * Created by pc on 2019/2/21.
 */
public class ActTitleFeatureDo implements Serializable {
    private static final long serialVersionUID = 6695201251295150673L;


    /**
     * 静态特征，推荐入参提供
     */

    private Long appId; //媒体ID f.请求 f201000-f201001

    private Long slotId;  //广告位ID f.请求 f108000-f108001

    private Long activityId; //活动IDf.请求 f302000-f302001

    private Long activityPage; //自定义活动ID f.请求 新增，待编码 311001

    private String activitySkin; //皮肤ID f.请求 新增，待编码

    private Long dsm2A; //返回拦截类型 f.请求 新增，待编码  312001


    private Long areaCode; // 地域 f4010030


    /**
     * 动态特征，打印日志补全、算法推荐内部补全
     */
    private Long activityTitleId; //主标题ID.请求

    private Long activitySubTitleId; //副标题ID.请求

    private Long activityTitleTagId; //主标题标签ID.请求

    private Long activitySubTitleTagId; //副标题标签ID.请求

    private String activityTitleName; //主标题名称.请求

    private String activitySubTitleName; //副标题名称.请求


    private Long  activitySubTitlePrizeId ;//副标题奖品ID

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getActivityPage() {
        return activityPage;
    }

    public void setActivityPage(Long activityPage) {
        this.activityPage = activityPage;
    }

    public String getActivitySkin() {
        return activitySkin;
    }

    public void setActivitySkin(String activitySkin) {
        this.activitySkin = activitySkin;
    }

    public Long getDsm2A() {
        return dsm2A;
    }

    public void setDsm2A(Long dsm2A) {
        this.dsm2A = dsm2A;
    }

    public Long getAreaCode() {
        return areaCode;
    }

    public void setAreaCode(Long areaCode) {
        this.areaCode = areaCode;
    }

    public Long getActivityTitleId() {
        return activityTitleId;
    }

    public void setActivityTitleId(Long activityTitleId) {
        this.activityTitleId = activityTitleId;
    }

    public Long getActivitySubTitleId() {
        return activitySubTitleId;
    }

    public void setActivitySubTitleId(Long activitySubTitleId) {
        this.activitySubTitleId = activitySubTitleId;
    }

    public Long getActivityTitleTagId() {
        return activityTitleTagId;
    }

    public void setActivityTitleTagId(Long activityTitleTagId) {
        this.activityTitleTagId = activityTitleTagId;
    }

    public Long getActivitySubTitleTagId() {
        return activitySubTitleTagId;
    }

    public void setActivitySubTitleTagId(Long activitySubTitleTagId) {
        this.activitySubTitleTagId = activitySubTitleTagId;
    }

    public String getActivityTitleName() {
        return activityTitleName;
    }

    public void setActivityTitleName(String activityTitleName) {
        this.activityTitleName = activityTitleName;
    }

    public String getActivitySubTitleName() {
        return activitySubTitleName;
    }

    public void setActivitySubTitleName(String activitySubTitleName) {
        this.activitySubTitleName = activitySubTitleName;
    }

    public Long getActivitySubTitlePrizeId() {
        return activitySubTitlePrizeId;
    }

    public void setActivitySubTitlePrizeId(Long activitySubTitlePrizeId) {
        this.activitySubTitlePrizeId = activitySubTitlePrizeId;
    }
}
